@@ -36,19 +36,14 @@ class BlackRock:
     def return_hdr(self):
         """Return the header for further use.
 
-        Parameters
-        ----------
-        trigger_bits : int, optional
-            8 or 16, read the triggers as one or two bytes
-        trigger_zero : bool, optional
-            read the trigger zero or not
-
         Returns
         -------
         subj_id : str
             subject identification code
         start_time : datetime
-            start time of the dataset
+            start time of the dataset (in UTC time, because that's the way it
+            was saved and there is no way to know the correct local time
+            reliably)
         s_freq : float
             sampling frequency
         chan_name : list of str
@@ -142,13 +137,20 @@ class BlackRock:
 
         return data[chan, :]
 
-    def return_markers(self, trigger_bits=8, trigger_zero=True):
-        """We always read triggers as 16bit, but we convert them to 8 here
-        if requested.
-
+    def return_markers(self, trigger_bits=16, trigger_zero=True):
+        """
+        Parameters
+        ----------
+        trigger_bits : int, optional
+            8 or 16, read the triggers as one or two bytes
+        trigger_zero : bool, optional
+            read the trigger zero or not
         """
         nev_file = splitext(self.filename)[0] + '.nev'
-        markers = _read_neuralev(nev_file, read_markers=True)
+        markers = _read_neuralev(
+            nev_file,
+            read_markers=True,
+            trigger_bits=16)
 
         if trigger_bits == 8:
             to8 = lambda x: str(int(x) - (256 ** 2 - 256))
@@ -164,7 +166,7 @@ class BlackRock:
                     markers[i]['end'] = markers[i + 1]['start']
                 markers_no_zero.append(markers[i])
 
-        return markers_no_zero
+            return markers_no_zero
 
 
 def _read_nsx(filename, BOData, sess_begin, sess_end, factor, begsam, endsam):
@@ -273,16 +275,9 @@ def _read_neuralcd(filename):
                                   unpack('<i', BasicHdr[278:282])[0])
         time = unpack('<' + 'H' * 8, BasicHdr[286:302])
         lg.info('The date/time from the header is stored in UTC, which is stored in DateTimeUTC')
-        hdr['DateTimeUTC'] = datetime(time[0], time[1], time[3], time[4], time[5],
+        hdr['DateTime'] = datetime(time[0], time[1], time[3], time[4], time[5],
                                    time[6], time[7] * 1000,
                                    tzinfo=timezone.utc)
-        try:
-            lg.debug('Trying to get date/time from filename')
-            hdr['DateTime'] = datetime.strptime(filename.stem[:15], '%Y%m%d-%H%M%S')
-        except Exception:
-            lg.warning('Cannot decode date/time from filename, using UTC time from header')
-            hdr['DateTime'] = hdr['DateTimeUTC']
-
         hdr['ChannelCount'] = unpack('<I', BasicHdr[302:306])[0]
 
         ExtHdrLength = 66
@@ -375,8 +370,7 @@ def _read_neuralcd(filename):
     return hdr
 
 
-def _read_neuralev(filename, read_markers=False, trigger_bits=16,
-                   trigger_zero=True):
+def _read_neuralev(filename, read_markers=False, trigger_bits=16):
     """Read some information from NEV
 
     Parameters
@@ -387,8 +381,6 @@ def _read_neuralev(filename, read_markers=False, trigger_bits=16,
         whether to read markers or not (it can get really large)
     trigger_bits : int, optional
         8 or 16, read the triggers as one or two bytes
-    trigger_zero : bool, optional
-        read the trigger zero or not
 
     Returns
     -------
@@ -435,14 +427,8 @@ def _read_neuralev(filename, read_markers=False, trigger_bits=16,
         time = unpack('<' + 'H' * 8, BasicHdr[i0:i1])
         lg.debug('DateTime is in local time with Central version <= 6.03'
                  ' and in UTC with Central version > 6.05')
-        hdr['DateTimeUTC'] = datetime(time[0], time[1], time[3],
-                                      time[4], time[5], time[6], time[7] * 1000)
-        try:
-            lg.debug('Trying to get date/time from filename')
-            hdr['DateTime'] = datetime.strptime(filename.stem[:15], '%Y%m%d-%H%M%S')
-        except Exception:
-            lg.warning('Cannot decode date/time from filename, using (probable) UTC time from header')
-            hdr['DateTime'] = hdr['DateTimeUTC']
+        hdr['DateTime'] = datetime(time[0], time[1], time[3],
+                                   time[4], time[5], time[6], time[7] * 1000)
 
         i0, i1 = i1, i1 + 32
         # hdr['Application'] = _str(BasicHdr[i0:i1].decode('utf-8'))
@@ -560,8 +546,7 @@ def _read_neuralev(filename, read_markers=False, trigger_bits=16,
                        'tempClassOrReason': unpack('<B', x[6 + i:7 + i])[0],
                        'tempDigiVals': tempDigiVals}
 
-                if tempDigiVals != 0 or False:
-                    DigiValues.append(val)
+                DigiValues.append(val)
 
             digserPacketID = 0
             not_serialdigital = [x for x in DigiValues
